@@ -1,11 +1,10 @@
 #' causal.decomp: Causal Decomposition Analysis.
-#' 
-#' The causal.decomp package provides four important functions:
-#' mmi, smi, pocr, and sensitivity.
-#' 
-#' @docType package
-#' @name causal.decomp
-#' 
+#'
+#' The causal.decomp package provides six important functions:
+#' mmi, smi, pocr, sensitivity, ind.decomp, and ind.sens.
+#'
+"_PACKAGE"
+#'
 #' @importFrom MASS gamma.shape polr
 #' @importFrom nnet multinom
 #' @importFrom PSweight SumStat
@@ -16,5 +15,14 @@
 #'   predict quantile rbinom rgamma rmultinom
 #'   rnorm rpois terms update
 #' @importFrom utils packageDescription
+#' @importFrom rlang exprs
+#' @importFrom modelObj buildModelObj
+#' @importFrom DynTxRegime optimalClass optTx
+#' @importFrom rpart rpart rpart.control
+#' @importFrom magrittr %>%
+#' @importFrom dplyr mutate
+#' @importFrom parallel mclapply
+#' @importFrom distr AbscontDistribution r
+#' @importFrom knitr kable
 NULL
-#> NULL
\ No newline at end of file
+#> NULL
