@@ -10,16 +10,16 @@ combine <- function(fit.r, fit.x, fit.m, fit.y, func, weights){
     ## Calculate weighted outcome from R model
     if(!is.null(fit.r) && isCBPS.r){
       y.data$w <- fit.r$weights
-      prop.treat <- table(y.data[, treat])/nrow(y.data)
+      prop.group <- table(y.data[, group])/nrow(y.data)
     } else if(!is.null(fit.r) && isSumStat.r){
       y.data$w <- fit.r$ps.weights[, 3]
-      prop.treat <- table(y.data[, treat])/nrow(y.data)
+      prop.group <- table(y.data[, group])/nrow(y.data)
     } else {
       y.data$w <- rep(1, n.y)
-      prop.treat <- rep(1, length(levels(y.data[, treat])))
+      prop.group <- rep(1, length(levels(y.data[, group])))
     }
     
-    wy <- rep(NA, length(levels(y.data[, treat])))
+    wy <- rep(NA, length(levels(y.data[, group])))
     if(isGlm.y){ ## fixed 8/27/2021 for conditional = T
       y.data$pred.prob <- predict(fit.y, newdata = y.data, type = "response")
       if(conditional){
@@ -34,28 +34,28 @@ combine <- function(fit.r, fit.x, fit.m, fit.y, func, weights){
         wy.f <- as.formula(paste(outcome, "~ 1"))
       }
     }
-    for(i in 1:length(levels(y.data[, treat]))){
-      wy[i] <- lm(wy.f, weights = w * prop.treat[i],
-                  data = y.data[y.data[, treat] == levels(y.data[, treat])[i], ])$coef[1]
+    for(i in 1:length(levels(y.data[, group]))){
+      wy[i] <- lm(wy.f, weights = w * prop.group[i],
+                  data = y.data[y.data[, group] == levels(y.data[, group])[i], ])$coef[1]
     }
   }
   
   if(func == "mmi" | func == "smi"){
-    environment(select.treat) <- environment()
-    # Do all combinations, ref.lev.treat vs. sel.lev.treat
+    environment(select_group) <- environment()
+    # Do all combinations, ref.lev.group vs. sel.lev.group
     res <- NULL
-    for(l in 2:length(levels(y.data[, treat]))){
-      res <- c(res, select.treat(fit.m = fit.m, fit.y = fit.y, sel.lev.treat = l,
-                                     ref.lev.treat = 1,
-                                     prop.treat = prop.treat, wy = wy, func = func, weights = weights))
+    for(l in 2:length(levels(y.data[, group]))){
+      res <- c(res, select_group(fit.m = fit.m, fit.y = fit.y, sel.lev.group = l,
+                                     ref.lev.group = 1,
+                                     prop.group = prop.group, wy = wy, func = func, weights = weights))
     }
   } else if (func == "pocr"){
-    environment(select.treat.pocr) <- environment()
-    # Do all combinations, ref.lev.treat vs. sel.lev.treat
+    environment(select_group_pocr) <- environment()
+    # Do all combinations, ref.lev.group vs. sel.lev.group
     res <- NULL
-    for(l in 2:length(levels(y.data[, treat]))){
-      res <- c(res, select.treat.pocr(fit.x = fit.x, fit.m = fit.m, fit.y = fit.y, sel.lev.treat = l,
-                                      ref.lev.treat = 1))
+    for(l in 2:length(levels(y.data[, group]))){
+      res <- c(res, select_group_pocr(fit.x = fit.x, fit.m = fit.m, fit.y = fit.y, sel.lev.group = l,
+                                      ref.lev.group = 1))
     }
   }
   
