@@ -33,7 +33,7 @@ combine.b <- function(XX, fit.r, fit.x, fit.m, fit.y, cluster = NULL, func){
         ps.xvar[name] <- substr(ps.xvar[name], 1, nchar(ps.xvar[name]) - 1)
       }
     }
-    ps.formula <- as.formula(paste(treat, paste(ps.xvar, collapse = " + "), sep = " ~ "))
+    ps.formula <- as.formula(paste(group, paste(ps.xvar, collapse = " + "), sep = " ~ "))
     fit.r.b <- SumStat(ps.formula = ps.formula, data = y.data.b,
                        trtgrp = fit.r$trtgrp, weight = "IPW")
   } else {
