@@ -3,7 +3,7 @@ if(getRversion() >= "2.10") {
                            "covariates", "isCBPS.r", "isGlm.m", "isGlm.y", "isLm.m",
                            "isMultiConfounders", "isNominal.m", "isOrdinal.m",
                            "isSumStat.r", "n.y", "num.ms", "outcome", "pfun", "phi1",
-                           "treat", "w", "y.data",
+                           "group", "w", "y.data",
                            "model.weights", "par", "contour", "points", "text",
                            "relevel", "vcov", "X", "cov", "var", "qnorm",
                            "weights"))
