@@ -3,34 +3,33 @@
 #' 'mmi' is used to estimate the initial disparity, disparity reduction, and
 #' disparity remaining for causal decomposition analysis, using the
 #' multiple-mediator-imputation estimation method proposed by Park et al. (2020).
+#' This estimator was originally developed to handle multiple mediators simultaneously;
+#' however, it can also be applied to a single mediator.
 #' 
 #' @usage 
-#' mmi(fit.r = NULL, fit.x, fit.y, treat, covariates, sims = 100, conf.level = .95,
+#' mmi(fit.r = NULL, fit.x, fit.y, group, covariates, sims = 100, conf.level = .95,
 #'     conditional = TRUE, cluster = NULL, long = TRUE, mc.cores = 1L, seed = NULL)
 #'
 #' @details This function returns the point estimates of the initial disparity,
 #'   disparity reduction, and disparity remaining for a categorical
-#'   treatment and a variety of types of outcome and mediator(s) in causal
-#'   decomposition analysis. It also returns nonparametric
+#'   social group indicator and a variety of types of outcome and
+#'   mediator(s) in causal decomposition analysis. It also returns nonparametric
 #'   percentile bootstrap confidence intervals for each estimate.
-#'
-#'   The initial disparity represents the expected difference in an outcome between
-#'   a comparison group \eqn{R=j} and a reference group \eqn{R=i} where \eqn{i \neq j}{i != j}.
-#'   That is,
-#'   \deqn{\tau(i,j) \ = \ E\{Y|R=j\} - E\{Y|R=i\},}{%
-#'         \delta(i,j) = E[Y|R=j] - E[Y|R=i],}
-#'   where \eqn{R} and \eqn{Y} are the group indicator and the outcome variable, respectively.
-#'   The disparity reduction represents the expected change in an outcome for the group \eqn{R=j}
-#'   after adjusting the level of mediator(s) to the level of the reference group.
-#'   That is,
-#'   \deqn{\delta(j) \ = \ E\{Y|R=j\} - E\{Y(G_M(i))|R=j\},}{%
-#'         \delta(j) = E[Y|R=j] - E[Y(G_M(i))|R=j],}
-#'   where \eqn{G_M(i)}{G_M(i)} is a random draw from the mediator distribution of
-#'   the reference group.
-#'   The disparity remaining represents the remaining disparity for the group \eqn{R=j}
-#'   even after adjusting the level of mediators to the reference group. Formally,
-#'   \deqn{\zeta(i) \ = \ E\{Y(G_M(i))|R=j\} - E\{Y|R=i\}.}{%
-#'         \zeta(i) = E[Y(G_M(i))|R=j] - E[Y|R=i].}
+#'   
+#'   The initial disparity between two groups is defined as \eqn{\tau(r,0) \equiv E[Y|R=r,c]-E[Y|R=0,c]},
+#'   for \eqn{c \in \mathcal{C}} and \eqn{r \mathcal{R}}, where \eqn{R=0} denotes the reference group and
+#'   \eqn{R=r} is the comparison group. 
+#'   
+#'   The disparity reduction, conditional on baseline covariates, measures how much the initial disparity
+#'   would shrink if we simultaneously equalized the distribution of the mediators W and M across groups
+#'   within each level of \eqn{C}. Formally, \eqn{\delta(1)\equiv E[Y|R=1,c]-E[Y(G_{w|c}(0)G_{m|c}(0))|R=1,c]},
+#'   where \eqn{G_{m|c}(0)} and \eqn{G_{w|c}(0)} are a random draw from the reference group’s mediator \eqn{M}
+#'   and \eqn{W} distribution given \eqn{C}, respectively. 
+#'   
+#'   The remaining disparity, also conditional on \eqn{C}, is the difference between the reference group’s
+#'   observed outcome and the counterfactual outcome for the comparison group after equalizing \eqn{M}.
+#'   Formally, \eqn{\zeta(0) \equiv E[Y(Y(G_{w|c}(0)G_{m|c}(0)))|R=1, c]-E[Y|R=0, c]}.
+#'   
 #'   The disparity reduction and remaining can be estimated using the
 #'   multiple-mediator-imputation method suggested by Park et al. (2020).
 #'   See the references for more details.
@@ -43,10 +42,10 @@
 #'   linear regression models and generalized linear models, multinomial
 #'   log-linear models, and ordered response models.
 #'   The outcome model ('fit.y') can be of class 'lm' or 'glm'.
-#'   Also, the treatment model ('fit.r') can be of class 'CBPS' or 'SumStat', both of
+#'   Also, the social group model ('fit.r') can be of class 'CBPS' or 'SumStat', both of
 #'   which use the propensity score weighting. It is only necessary when 'conditional = FALSE'.
 #'
-#' @param fit.r a fitted model object for treatment. Can be of class 'CBPS' or
+#' @param fit.r a fitted model object for social group indicator (treatment). Can be of class 'CBPS' or
 #'   'SumStat'. Default is 'NULL'. Only necessary if 'conditional' is 'FALSE'.
 #' @param fit.x a fitted model object for intermediate confounder(s). Each intermediate
 #'   model can be of class 'lm', 'glm', 'multinom', or 'polr'. When multiple confounders
@@ -57,9 +56,9 @@
 #'   which are estimated by the nonparametric percentile bootstrap method.
 #'   Default is .95, which returns the 2.5 and 97.5 percentiles of the simulated
 #'   quantities.
-#' @param treat a character string indicating the name of the treatment variable
-#'   used in the models. The treatment can be categorical with two or more
-#'   categories (two- or multi-valued factor).
+#' @param group a character string indicating the name of the social group indicator
+#'   such as race or gender (treatment) used in the models. The social group indicator
+#'   can be categorical with two or more categories (two- or multi-valued factor).
 #' @param covariates a vector containing the name of the covariate variable(s)
 #'   used in the models. Each covariate can be categorical with two or more
 #'   categories (two- or multi-valued factor) or continuous (numeric).
@@ -84,18 +83,20 @@
 #'   if 'long' is 'TRUE'.}
 #'
 #' @author
-#'   Suyeon Kang, University of California, Riverside, \email{skang062@@ucr.edu};
+#'   Suyeon Kang, University of Central Florida, \email{suyeon.kang@@ucf.edu};
 #'   Soojin Park, University of California, Riverside, \email{soojinp@@ucr.edu}.
 #'
 #' @seealso \code{\link{smi}}
 #'
 #' @references
-#'   Park, S., Lee, C., and Qin, X. (2020). "Estimation and sensitivity analysis
-#'   for causal decomposition in heath disparity research", Sociological Methods & Research, 00491241211067516.
-#'
-#'   Park, S., Kang, S., and Lee, C. (2021+). "Choosing an optimal method for causal
-#'   decomposition analysis: A better practice for identifying contributing factors to
-#'   health disparities". arXiv preprint arXiv:2109.06940.
+#' 
+#'   Park, S., Qin, X., & Lee, C. (2022). "Estimation and sensitivity analysis for causal
+#'   decomposition in health disparity research". Sociological Methods & Research, 53(2),
+#'   571-602.
+#'   
+#'   Park, S., Kang, S., & Lee, C. (2023). "Choosing an Optimal Method for Causal Decomposition
+#'   Analysis with Continuous Outcomes: A Review and Simulation Study". Sociological Methodology,
+#'   54(1), 92-117.
 #'
 #' @export
 #' @examples
@@ -123,7 +124,7 @@
 #'
 #' res.1a <- mmi(fit.r = fit.r1, fit.x = fit.x1,
 #'           fit.y = fit.y1, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1a
 #'
 #' #------------------------------------------------------------------------------#
@@ -134,7 +135,7 @@
 #'
 #' res.1b <- mmi(fit.r = fit.r1, fit.x = fit.x1,
 #'           fit.y = fit.y2, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1b}
 #' 
 #' #------------------------------------------------------------------------------#
@@ -160,7 +161,7 @@
 #'
 #' res.2a <- mmi(fit.x = fit.x2,
 #'           fit.y = fit.y1, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2a}
 #' 
 #' #------------------------------------------------------------------------------#
@@ -171,10 +172,24 @@
 #'
 #' res.2b <- mmi(fit.x = fit.x2,
 #'           fit.y = fit.y2, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2b}
+#' 
+#' #------------------------------------------------------------------------------#
+#' # Example 3: Case with Multiple Intermediate Confounders
+#' #------------------------------------------------------------------------------#
+#' \donttest{fit.r <- SumStat(R ~ C, data = idata, weight = "IPW")
+#' fit.x1 <- lm(X1 ~ R + C, data = idata)
+#' fit.x2 <- lm(X2 ~ R + C, data = idata)
+#' fit.x3 <- lm(X3 ~ R + C, data = idata)
+#' fit.y <- lm(Y ~ R + M + X1 + X2 + X3 + C, data = idata)
+#' 
+#' res.3 <- mmi(fit.r = fit.r, fit.x = list(fit.x1, fit.x2, fit.x3),
+#'          fit.y = fit.y, sims = 40, conditional = FALSE,
+#'          covariates = "C", group = "R", seed = 111)
+#'          res.3}
 mmi <- function(fit.r = NULL, fit.x, fit.y,
-                treat, covariates, sims = 100, conf.level = .95,
+                group, covariates, sims = 100, conf.level = .95,
                 conditional = TRUE, cluster = NULL, long = TRUE,
                 mc.cores = 1L, seed = NULL){
 
@@ -186,15 +201,15 @@ mmi <- function(fit.r = NULL, fit.x, fit.y,
 
   # Warning for inappropriate settings
   if(!is.null(fit.r) && conditional){
-    stop("treatment model must be NULL when conditional = TRUE")
+    stop("social group (treatment) model must be NULL when conditional = TRUE")
   }
 
   if(is.null(fit.r) && !conditional){
-    stop("treatment model must be specified when conditional = FALSE")
+    stop("social group (treatment) model must be specified when conditional = FALSE")
   }
 
-  if(length(treat) >= 2){
-    stop("only one variable must be selected for 'treat'")
+  if(length(group) >= 2){
+    stop("only one variable must be selected for 'group'")
   }
 
   if(conf.level <= 0 | conf.level >= 1){
@@ -251,7 +266,7 @@ mmi <- function(fit.r = NULL, fit.x, fit.y,
   }
 
   if(!is.null(fit.r) && !isCBPS.r && !isSumStat.r){
-    stop("unsupported treatment model")
+    stop("unsupported social group (treatment) model")
   }
 
   if(!isGlm.y && !isLm.y){
@@ -289,7 +304,7 @@ mmi <- function(fit.r = NULL, fit.x, fit.y,
     }
   } else if (!is.null(n.r)){
     if(n.m != n.y | n.r != n.y | n.m != n.r){
-      stop("number of observations do not match between treatment,
+      stop("number of observations do not match between social group (treatment),
            mediator and outcome models")
     }
   }
@@ -336,27 +351,27 @@ mmi <- function(fit.r = NULL, fit.x, fit.y,
   }
   weights <- weights.y
 
-  # Extract treatment and outcome variable names from models
+  # Extract social group (treatment) and outcome variable names from models
   if(!is.null(fit.r)){
     if(isCBPS.r){
-      treat0 <- all.vars(formula(fit.r))[[1]]
+      group0 <- all.vars(formula(fit.r))[[1]]
     } else if(isSumStat.r){
-      treat0 <- names(fit.r$ps.weight)[[1]]
+      group0 <- names(fit.r$ps.weight)[[1]]
     }
-    if(treat != treat0){
-      stop("response variable of 'fit.r' and specified 'treat' do not match")
+    if(group != group0){
+      stop("response variable of 'fit.r' and specified 'group' do not match")
     } else {
-      treat <- treat0
+      group <- group0
     }
   }
-  r <- length(levels(y.data[, treat]))
+  r <- length(levels(y.data[, group]))
   outcome <- all.vars(formula(fit.y))[[1]]
 
   # Bootstrap QoI
   message("Running nonparametric bootstrap\n")
 
   # Make objects available to all functions
-  environment(combine.b) <- environment(combine) <- environment(select.treat) <- environment()
+  environment(combine.b) <- environment(combine) <- environment(select_group) <- environment()
 
   out <- matrix(NA, 3 * (r - 1), 3)
   all.out <- matrix(NA, 3 * (r - 1), sims)
@@ -364,13 +379,13 @@ mmi <- function(fit.r = NULL, fit.x, fit.y,
                      paste(conf.level * 100, "% CI Upper", sep = ""))
   rn <- rn2 <- NULL
   for(rr in 2:r){
-    rn <- c(rn, c(paste("Initial Disparity   (", levels(y.data[, treat])[1],
-                        " vs ", levels(y.data[, treat])[rr], ")", sep = ""),
-                  paste("Disparity Remaining (", levels(y.data[, treat])[1],
-                        " vs ", levels(y.data[, treat])[rr], ")", sep = ""),
-                  paste("Disparity Reduction (", levels(y.data[, treat])[1],
-                        " vs ", levels(y.data[, treat])[rr], ")", sep = "")))
-    rn2 <- c(rn2, levels(y.data[, treat])[rr])
+    rn <- c(rn, c(paste("Initial Disparity   (", levels(y.data[, group])[1],
+                        " vs ", levels(y.data[, group])[rr], ")", sep = ""),
+                  paste("Disparity Remaining (", levels(y.data[, group])[1],
+                        " vs ", levels(y.data[, group])[rr], ")", sep = ""),
+                  paste("Disparity Reduction (", levels(y.data[, group])[1],
+                        " vs ", levels(y.data[, group])[rr], ")", sep = "")))
+    rn2 <- c(rn2, levels(y.data[, group])[rr])
   }
   
   summary0 <- mclapply(1:sims, combine.b, fit.r = fit.r, fit.x = NULL, fit.m = fit.m, fit.y = fit.y,
