@@ -2,15 +2,15 @@
 #'
 #' 'smi' is used to estimate the initial disparity, disparity reduction, and
 #' disparity remaining for causal decomposition analysis, using the
-#' single-mediator-imputation estimation method proposed by Park et al. (2021+).
+#' single-mediator-imputation estimation method described by Park, Kang, and Lee (2024).
 #' 
 #' @usage 
-#' smi(fit.r = NULL, fit.m, fit.y, treat, covariates, sims = 100, conf.level = .95,
+#' smi(fit.r = NULL, fit.m, fit.y, group, covariates, sims = 100, conf.level = .95,
 #'     conditional = TRUE, cluster = NULL, long = TRUE, mc.cores = 1L, seed = NULL)
 #'
 #' @details This function returns the point estimates of the initial disparity,
 #'   disparity reduction, and disparity remaining for a categorical
-#'   treatment and a variety of types of outcome and mediator(s) in causal
+#'   social group indicator (treatment) and a variety of types of outcome and mediator(s) in causal
 #'   decomposition analysis. It also returns nonparametric
 #'   percentile bootstrap confidence intervals for each estimate.
 #'
@@ -26,10 +26,10 @@
 #'   'multinom', or 'polr', corresponding respectively to the linear regression
 #'   models and generalized linear models, multinomial log-linear models, and
 #'   ordered response models. The outcome model ('fit.y') can be of class 'lm' or 'glm'.
-#'   Also, the treatment model ('fit.r') can be of class 'CBPS' or 'SumStat', both of
+#'   Also, the social group (treatment) model ('fit.r') can be of class 'CBPS' or 'SumStat', both of
 #'   which use the propensity score weighting. It is only necessary when 'conditional = FALSE'.
 #'
-#' @param fit.r a fitted model object for treatment. Can be of class 'CBPS' or
+#' @param fit.r a fitted model object for social group indicator (treatment). Can be of class 'CBPS' or
 #'   'SumStat'. Default is 'NULL'. Only necessary if 'conditional' is 'FALSE'.
 #' @param fit.m a fitted model object for mediator. Can be of class 'lm', 'glm',
 #'   'multinom', or 'polr'.
@@ -39,9 +39,9 @@
 #'   which are estimated by the nonparametric percentile bootstrap method.
 #'   Default is .95, which returns the 2.5 and 97.5 percentiles of the simulated
 #'   quantities.
-#' @param treat a character string indicating the name of the treatment variable
-#'   used in the models. The treatment can be categorical with two or more
-#'   categories (two- or multi-valued factor).
+#' @param group a character string indicating the name of the social group indicator
+#'   such as race or gender (treatment) used in the models. The social group indicator
+#'   can be categorical with two or more categories (two- or multi-valued factor).
 #' @param covariates a vector containing the name of the covariate variable(s)
 #'   used in the models. Each covariate can be categorical with two or more
 #'   categories (two- or multi-valued factor) or continuous (numeric).
@@ -65,22 +65,22 @@
 #'   disparity remaining, and disparity reduction for all bootstrap samples. Returned
 #'   if 'long' is 'TRUE'.}
 #'   \item{alpha.r}{a vector containing the estimates of the regression coefficient of
-#'   the treatment in the mediator. Not needed unless sensitivity analysis is
-#'   conducted afterwards.}
+#'   the social group indicator (treatment) in the mediator.
+#'   Not needed unless sensitivity analysis is conducted afterwards.}
 #'   \item{se.gamma}{a vector containing the estimates of standard error of the
 #'   egression coefficient of the mediator in the outcome model. Not needed unless
 #'   sensitivity analysis is conducted afterwards.}
 #'
 #' @author
-#'   Suyeon Kang, University of California, Riverside, \email{skang062@@ucr.edu};
+#'   Suyeon Kang, University of Central Florida, \email{suyeon.kang@@ucf.edu};
 #'   Soojin Park, University of California, Riverside, \email{soojinp@@ucr.edu}.
 #'
 #' @seealso \code{\link{mmi}}, \code{\link{sensitivity}}
 #'
 #' @references
-#'   Park, S., Kang, S., and Lee, C. (2021+). "Choosing an optimal method for causal
-#'   decomposition analysis: A better practice for identifying contributing factors to
-#'   health disparities". arXiv preprint arXiv:2109.06940.
+#'   Park, S., Kang, S., and Lee, C. (2024). "Choosing an optimal method for causal
+#'   decomposition analysis with continuous outcomes: A review and simulation study",
+#'   Sociological methodology, 54(1), 92-117.
 #'
 #' @export
 #' @examples
@@ -100,7 +100,7 @@
 #' fit.y1 <- lm(Y.num ~ R + M.num + X + C.num + C.bin, data = sdata)
 #' res.1a1 <- smi(fit.r = fit.r1, fit.m = fit.m1,
 #'           fit.y = fit.y1, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 32)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 32)
 #' res.1a1
 #'
 #' \donttest{# Binary mediator
@@ -109,7 +109,7 @@
 #' fit.y2 <- lm(Y.num ~ R + M.bin + X + C.num + C.bin, data = sdata)
 #' res.1a2 <- smi(fit.r = fit.r1, fit.m = fit.m2,
 #'           fit.y = fit.y2, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1a2
 #'
 #' # Categorical mediator
@@ -118,14 +118,14 @@
 #' fit.y3 <- lm(Y.num ~ R + M.cat + X + C.num + C.bin, data = sdata)
 #' res.1a3 <- smi(fit.r = fit.r1, fit.m = fit.m3,
 #'           fit.y = fit.y3, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1a3
 #'
 #' require(nnet)
 #' fit.m4 <- multinom(M.cat ~ R + C.num + C.bin, data = sdata)
 #' res.1a4 <- smi(fit.r = fit.r1, fit.m = fit.m4,
 #'           fit.y = fit.y3, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1a4}
 #' 
 #' #------------------------------------------------------------------------------#
@@ -136,7 +136,7 @@
 #'           data = sdata, family = binomial(link = "logit"))
 #' res.1b1 <- smi(fit.r = fit.r1, fit.m = fit.m1,
 #'           fit.y = fit.y1, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 32)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 32)
 #' res.1b1
 #'
 #' # Binary mediator
@@ -144,7 +144,7 @@
 #'           data = sdata, family = binomial(link = "logit"))
 #' res.1b2 <- smi(fit.r = fit.r1, fit.m = fit.m2,
 #'           fit.y = fit.y2, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1b2
 #'
 #' # Categorical mediator
@@ -152,12 +152,12 @@
 #'           data = sdata, family = binomial(link = "logit"))
 #' res.1b3 <- smi(fit.r = fit.r1, fit.m = fit.m3,
 #'           fit.y = fit.y3, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1b3
 #'
 #' res.1b4 <- smi(fit.r = fit.r1, fit.m = fit.m4,
 #'           fit.y = fit.y3, sims = 40, conditional = FALSE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.1b4}
 #'
 #' #---------------------------------------------------------------------------------#
@@ -177,7 +177,7 @@
 #' fit.m1 <- lm(M.num ~ R + C.num + C.bin, data = sdata.c)
 #' res.2a1 <- smi(fit.m = fit.m1,
 #'           fit.y = fit.y1, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2a1
 #'
 #' # Binary mediator
@@ -186,7 +186,7 @@
 #'           family = binomial(link = "logit"))
 #' res.2a2 <- smi(fit.m = fit.m2,
 #'           fit.y = fit.y2, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2a2
 #'
 #' # Categorical mediator
@@ -194,13 +194,13 @@
 #' fit.m3 <- polr(M.cat ~ R + C.num + C.bin, data = sdata.c)
 #' res.2a3 <- smi(fit.m = fit.m3,
 #'           fit.y = fit.y3, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2a3
 #'
 #' fit.m4 <- multinom(M.cat ~ R + C.num + C.bin, data = sdata.c)
 #' res.2a4 <- smi(fit.m = fit.m4,
 #'           fit.y = fit.y3, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2a4}
 #'
 #' #------------------------------------------------------------------------------#
@@ -211,7 +211,7 @@
 #'           data = sdata.c, family = binomial(link = "logit"))
 #' res.2b1 <- smi(fit.m = fit.m1,
 #'           fit.y = fit.y1, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2b1
 #'
 #' # Binary mediator
@@ -219,7 +219,7 @@
 #'           data = sdata.c, family = binomial(link = "logit"))
 #' res.2b2 <- smi(fit.m = fit.m2,
 #'           fit.y = fit.y2, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2b2
 #'
 #' # Categorical mediator
@@ -227,15 +227,15 @@
 #'           data = sdata.c, family = binomial(link = "logit"))
 #' res.2b3 <- smi(fit.m = fit.m3,
 #'           fit.y = fit.y3, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2b3
 #'
 #' res.2b4 <- smi(fit.m = fit.m4,
 #'           fit.y = fit.y3, sims = 40, conditional = TRUE,
-#'           covariates = c("C.num", "C.bin"), treat = "R", seed = 111)
+#'           covariates = c("C.num", "C.bin"), group = "R", seed = 111)
 #' res.2b4}
 smi <- function(fit.r = NULL, fit.m, fit.y,
-                treat, covariates, sims = 100, conf.level = .95,
+                group, covariates, sims = 100, conf.level = .95,
                 conditional = TRUE, cluster = NULL, long = TRUE,
                 mc.cores = 1L, seed = NULL){
   
@@ -245,15 +245,15 @@ smi <- function(fit.r = NULL, fit.m, fit.y,
 
   # Warning for inappropriate settings
   if(!is.null(fit.r) && conditional){
-    stop("treatment model must be NULL when conditional = TRUE")
+    stop("social group (treatment) model must be NULL when conditional = TRUE")
   }
 
   #if(is.null(fit.r) && !conditional){
-  #  stop("treatment model must be specified when conditional = FALSE")
+  #  stop("social group (treatment) model must be specified when conditional = FALSE")
   #}
 
-  if(length(treat) >= 2){
-    stop("only one variable must be selected for 'treat'")
+  if(length(group) >= 2){
+    stop("only one variable must be selected for 'group'")
   }
 
   if(conf.level <= 0 | conf.level >= 1){
@@ -296,7 +296,7 @@ smi <- function(fit.r = NULL, fit.m, fit.y,
   }
 
   if(!is.null(fit.r) && !isCBPS.r && !isSumStat.r){
-    stop("unsupported treatment model")
+    stop("unsupported social group (treatment) model")
   }
 
   if(!isGlm.y && !isLm.y){
@@ -325,7 +325,7 @@ smi <- function(fit.r = NULL, fit.m, fit.y,
     }
   } else if (!is.null(n.r)){
     if(n.m != n.y | n.r != n.y | n.m != n.r){
-      stop("number of observations do not match between treatment,
+      stop("number of observations do not match between social group (treatment),
            mediator and outcome models")
     }
   }
@@ -368,27 +368,27 @@ smi <- function(fit.r = NULL, fit.m, fit.y,
   }
   weights <- weights.y
 
-  # Extract treatment and outcome variable names from models
+  # Extract social group (treatment) and outcome variable names from models
   if(!is.null(fit.r)){
     if(isCBPS.r){
-      treat0 <- all.vars(formula(fit.r))[[1]]
+      group0 <- all.vars(formula(fit.r))[[1]]
     } else if(isSumStat.r){
-      treat0 <- names(fit.r$ps.weight)[[1]]
+      group0 <- names(fit.r$ps.weight)[[1]]
     }
-    if(treat != treat0){
-      stop("response variable of 'fit.r' and specified 'treat' do not match")
+    if(group != group0){
+      stop("response variable of 'fit.r' and specified 'group' do not match")
     } else {
-      treat <- treat0
+      group <- group0
     }
   }
-  r <- length(levels(y.data[, treat]))
+  r <- length(levels(y.data[, group]))
   outcome <- all.vars(formula(fit.y))[[1]]
 
   # Bootstrap QoI
   message("Running nonparametric bootstrap\n")
 
   # Make objects available to all functions
-  environment(combine.b) <- environment(combine) <- environment(select.treat) <- environment()
+  environment(combine.b) <- environment(combine) <- environment(select_group) <- environment()
 
   out <- matrix(NA, 3 * (r - 1), 3)
   all.out <- matrix(NA, 3 * (r - 1), sims)
@@ -396,13 +396,13 @@ smi <- function(fit.r = NULL, fit.m, fit.y,
                      paste(conf.level * 100, "% CI Upper", sep = ""))
   rn <- rn2 <- NULL
   for(rr in 2:r){
-    rn <- c(rn, c(paste("Initial Disparity   (", levels(y.data[, treat])[1],
-                        " vs ", levels(y.data[, treat])[rr], ")", sep = ""),
-                  paste("Disparity Remaining (", levels(y.data[, treat])[1],
-                        " vs ", levels(y.data[, treat])[rr], ")", sep = ""),
-                  paste("Disparity Reduction (", levels(y.data[, treat])[1],
-                        " vs ", levels(y.data[, treat])[rr], ")", sep = "")))
-    rn2 <- c(rn2, levels(y.data[, treat])[rr])
+    rn <- c(rn, c(paste("Initial Disparity   (", levels(y.data[, group])[1],
+                        " vs ", levels(y.data[, group])[rr], ")", sep = ""),
+                  paste("Disparity Remaining (", levels(y.data[, group])[1],
+                        " vs ", levels(y.data[, group])[rr], ")", sep = ""),
+                  paste("Disparity Reduction (", levels(y.data[, group])[1],
+                        " vs ", levels(y.data[, group])[rr], ")", sep = "")))
+    rn2 <- c(rn2, levels(y.data[, group])[rr])
   }
 
   summary0 <- mclapply(1:sims, combine.b, fit.r = fit.r, fit.x = NULL, fit.m = fit.m, fit.y = fit.y,
